Обёртка над vk_api с командным движком, базами данных  
[Быстрый старт](https://github.com/VK-SDK-DEV/VK-SDK/wiki/%D0%91%D1%8B%D1%81%D1%82%D1%80%D1%8B%D0%B9-%D1%81%D1%82%D0%B0%D1%80%D1%82)  
[Документация](https://github.com/VK-SDK-DEV/VK-SDK/wiki)